NLSL: ftwork.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
ftwork.f90 File Reference

Go to the source code of this file.

## Modules
module | ftwork

## Variables
double precision, dimension(mxpt), save | ftwork::work
double precision, dimension(mxpt), save | ftwork::work2
double precision, dimension(mxpt), save | ftwork::tmpclc
double precision, dimension(mxpt), save | ftwork::tmpdat